@@ -434,6 +434,15 @@ class Response:
             if isinstance(self._cached, str):
                 return self._cached
             raise RuntimeError("Cannot access text after getting content or json")
+
+        if (
+            "content-encoding" in self.headers
+            and self.headers["content-encoding"] == "gzip"
+        ):
+            raise ValueError(
+                "Content-encoding is gzip, data cannot be accessed as json or text. "
+                "Use content property to access raw bytes."
+            )
         self._cached = str(self.content, self.encoding)
         return self._cached
 
@@ -450,6 +459,14 @@ class Response:
         if not self._raw:
             self._raw = _RawResponse(self)
 
+        if (
+            "content-encoding" in self.headers
+            and self.headers["content-encoding"] == "gzip"
+        ):
+            raise ValueError(
+                "Content-encoding is gzip, data cannot be accessed as json or text. "
+                "Use content property to access raw bytes."
+            )
         try:
             obj = json.load(self._raw)
         except OSError:
